<?php

	/**
	 * Shortcode: heading
	 *
	 * @param array $atts Shortcode attributes
	 * @param string $content
	 * @return string Output html
	 */
	function su_heading_shortcode( $atts, $content = null ) {
		extract( shortcode_atts( array(
				'style' => 1
				), $atts ) );

		return '<div class="su-heading su-heading-style-' . $style . '"><div class="su-heading-shell">' . $content . '</div></div>';
	}

	/**
	 * Shortcode: frame
	 *
	 * @param array $atts Shortcode attributes
	 * @param string $content
	 * @return string Output html
	 */
	function su_frame_shortcode( $atts, $content = null ) {
		extract( shortcode_atts( array(
				'align' => 'left'
				), $atts ) );

		return '<div class="su-frame su-frame-align-' . $align . '"><div class="su-frame-shell">' . do_shortcode( $content ) . '</div></div>';
	}

	/**
	 * Shortcode: tabs
	 *
	 * @param array $atts Shortcode attributes
	 * @param string $content
	 * @return string Output html
	 */
	function su_tabs_shortcode( $atts, $content ) {
		extract( shortcode_atts( array(
				'style' => 1
				), $atts ) );

		$GLOBALS['tab_count'] = 0;

		do_shortcode( $content );

		if ( is_array( $GLOBALS['tabs'] ) ) {
			foreach ( $GLOBALS['tabs'] as $tab ) {
				$tabs[] = '<span>' . $tab['title'] . '</span>';
				$panes[] = '<div class="su-tabs-pane">' . $tab['content'] . '</div>';
			}
			$return = '<div class="su-tabs su-tabs-style-' . $style . '"><div class="su-tabs-nav">' . implode( '', $tabs ) . '</div><div class="su-tabs-panes">' . implode( "\n", $panes ) . '</div><div class="su-spacer"></div></div>';
		}

		// Unset globals
		unset( $GLOBALS['tabs'], $GLOBALS['tab_count'] );

		return $return;
	}

	/**
	 * Shortcode: tab
	 *
	 * @param array $atts Shortcode attributes
	 * @param string $content
	 * @return string Output html
	 */
	function su_tab_shortcode( $atts, $content ) {
		extract( shortcode_atts( array( 'title' => 'Tab %d' ), $atts ) );
		$x = $GLOBALS['tab_count'];
		$GLOBALS['tabs'][$x] = array( 'title' => sprintf( $title, $GLOBALS['tab_count'] ), 'content' => do_shortcode( $content ) );
		$GLOBALS['tab_count']++;
	}

	/**
	 * Shortcode: spoiler
	 *
	 * @param array $atts Shortcode attributes
	 * @param string $content
	 * @return string Output html
	 */
	function su_spoiler_shortcode( $atts, $content = null ) {
		extract( shortcode_atts( array(
				'title' => __( 'Spoiler title', 'satori' ),
				'open' => false,
				'style' => 1
				), $atts ) );

		$open_class = ( $open ) ? ' su-spoiler-open' : '';
		$open_display = ( $open ) ? ' style="display:block"' : '';

		return '<div class="su-spoiler su-spoiler-style-' . $style . $open_class . '"><div class="su-spoiler-title">' . $title . '</div><div class="su-spoiler-content"' . $open_display . '>' . su_do_shortcode( $content, 's' ) . '</div></div>';
	}

	/**
	 * Shortcode: accordion
	 *
	 * @param array $atts Shortcode attributes
	 * @param string $content
	 * @return string Output html
	 */
	function su_accordion_shortcode( $atts = null, $content = null ) {

		return '<div class="su-accordion">' . su_do_shortcode( $content, 'a' ) . '</div>';
	}

	/**
	 * Shortcode: divider
	 *
	 * @param array $atts Shortcode attributes
	 * @param string $content
	 * @return string Output html
	 */
	function su_divider_shortcode( $atts, $content = null ) {
		extract( shortcode_atts( array(
				'top' => false
				), $atts ) );

		return ( $top ) ? '<div class="su-divider-shell"><div class="su-divider"></div><a href="#">' . __( 'Top', 'satori' ) . '</a></div>' : '<div class="su-divider-shell"><div class="su-divider"></div></div>';
	}

	/**
	 * Shortcode: spacer
	 *
	 * @param array $atts Shortcode attributes
	 * @param string $content
	 * @return string Output html
	 */
	function su_spacer_shortcode( $atts, $content = null ) {
		extract( shortcode_atts( array(
				'size' => 0
				), $atts ) );

		return '<div class="su-spacer" style="height:' . $size . 'px"></div>';
	}

	/**
	 * Shortcode: highlight
	 *
	 * @param array $atts Shortcode attributes
	 * @param string $content
	 * @return string Output html
	 */
	function su_highlight_shortcode( $atts, $content = null ) {
		extract( shortcode_atts( array(
				'bg' => '#df9',
				'color' => '#000'
				), $atts ) );

		return '<span class="su-highlight" style="background:' . $bg . ';color:' . $color . '">&nbsp;' . $content . '&nbsp;</span>';
	}

	/**
	 * Shortcode: label
	 *
	 * @param array $atts Shortcode attributes
	 * @param string $content
	 * @return string Output html
	 */
	function su_label_shortcode( $atts, $content = null ) {
		extract( shortcode_atts( array(
				'style' => 'default'
				), $atts ) );

		return '<span class="su-label su-label-style-' . $style . '">' . $content . '</span>';
	}

	/**
	 * Shortcode: dropcap
	 *
	 * @param array $atts Shortcode attributes
	 * @param string $content
	 * @return string Output html
	 */
	function su_dropcap_shortcode( $atts, $content = null ) {
		extract( shortcode_atts( array(
				'style' => 1,
				'size' => 3
				), $atts ) );

		$em = $size * 0.5 . 'em';

		return '<span class="su-dropcap su-dropcap-style-' . $style . '" style="font-size:' . $em . '">' . $content . '</span>';
	}

	/**
	 * Shortcode: column
	 *
	 * @param array $atts Shortcode attributes
	 * @param string $content
	 * @return string Output html
	 */
	function su_column_shortcode( $atts, $content = null ) {
		extract( shortcode_atts( array(
				'size' => '1-2',
				'last' => false,
				'style' => 0
				), $atts ) );

		return ( $last ) ? '<div class="su-column su-column-' . $size . ' su-column-last su-column-style-' . $style . '">' . su_do_shortcode( $content, 'c' ) . '</div><div class="su-spacer"></div>' : '<div class="su-column su-column-' . $size . ' su-column-style-' . $style . '">' . su_do_shortcode( $content, 'c' ) . '</div>';
	}

	/**
	 * Shortcode: list
	 *
	 * @param array $atts Shortcode attributes
	 * @param string $content
	 * @return string Output html
	 */
	function su_list_shortcode( $atts, $content = null ) {
		extract( shortcode_atts( array(
				'style' => 'star'
				), $atts ) );

		return '<div class="su-list su-list-style-' . $style . '">' . do_shortcode( $content ) . '</div>';
	}

	/**
	 * Shortcode: quote
	 *
	 * @param array $atts Shortcode attributes
	 * @param string $content
	 * @return string Output html
	 */
	function su_quote_shortcode( $atts, $content = null ) {
		extract( shortcode_atts( array(
				'style' => 1
				), $atts ) );

		return '<div class="su-quote su-quote-style-' . $style . '"><div class="su-quote-shell">' . do_shortcode( $content ) . '</div></div>';
	}

	/**
	 * Shortcode: pullquote
	 *
	 * @param array $atts Shortcode attributes
	 * @param string $content
	 * @return string Output html
	 */
	function su_pullquote_shortcode( $atts, $content = null ) {
		extract( shortcode_atts( array(
				'style' => 1,
				'align' => 'left'
				), $atts ) );

		return '<div class="su-pullquote su-pullquote-style-' . $style . ' su-pullquote-align-' . $align . '">' . do_shortcode( $content ) . '</div>';
	}

	/**
	 * Shortcode: button
	 *
	 * @param array $atts Shortcode attributes
	 * @param string $content
	 * @return string Output html
	 */
	function su_button_shortcode( $atts, $content = null ) {
		extract( shortcode_atts( array(
				'link' => '#',
				'color' => '#aaa',
				'dark' => false,
				'radius' => 'auto',
				'square' => false,
				'style' => 1,
				'size' => 3,
				'icon' => false,
				'class' => 'su-button-class',
				'target' => false
				), $atts ) );

		// Old parameter compatibility, square
		$radius = ( $square ) ? 0 : $radius;

		$styles = array(
			'border_radius' => ( $radius == 'auto' ) ? round( $size + 2 ) : intval( $radius ),
			'dark_color' => su_hex_shift( $color, 'darker', 20 ),
			'light_color' => su_hex_shift( $color, 'lighter', 70 ),
			'size' => round( ( $size + 9 ) * 1.3 ),
			'text_color' => ( $dark ) ? su_hex_shift( $color, 'darker', 70 ) : su_hex_shift( $color, 'lighter', 90 ),
			'text_shadow' => ( $dark ) ? su_hex_shift( $color, 'lighter', 50 ) : su_hex_shift( $color, 'darker', 20 ),
			'text_shadow_position' => ( $dark ) ? '1px 1px' : '-1px -1px',
			'padding_v' => round( ( $size * 2 ) + 4 ),
			'padding_h' => round( ( ( $size * 3 ) + 10 ) )
		);

		$link_styles = array(
			'background-color' => $color,
			'border' => '0px solid ' . $styles['dark_color'],
			'border-radius' => $styles['border_radius'] . 'px',
			'-moz-border-radius' => $styles['border_radius'] . 'px',
			'-webkit-border-radius' => $styles['border_radius'] . 'px'
		);

		$span_styles = array(
			'color' => $styles['text_color'],
			'padding' => $styles['padding_v']+2 . 'px ' . $styles['padding_h'] . 'px ' . $styles['padding_v'] . 'px ' . $styles['padding_h'] . 'px',
			'font-size' => $styles['size'] . 'px',
			'height' => $styles['size'] . 'px',
			'line-height' => $styles['size'] . 'px',
			'border-radius' => $styles['border_radius'] . 'px',
			'text-shadow' => $styles['text_shadow_position'] . ' 0 ' . $styles['text_shadow'],
			'-moz-border-radius' => $styles['border_radius'] . 'px',
			'-moz-text-shadow' => $styles['text_shadow_position'] . ' 0 ' . $styles['text_shadow'],
			'-webkit-border-radius' => $styles['border_radius'] . 'px',
			'-webkit-text-shadow' => $styles['text_shadow_position'] . ' 0 ' . $styles['text_shadow']
		);

		$img_styles = array(
			'margin' => '0 ' . round( $size * 0.7 ) . 'px -' . round( ( $size * 0.3 ) + 4 ) . 'px -' . round( $size * 0.8 ) . 'px',
			'height' => ( $styles['size'] + 4 ) . 'px'
		);
		$link_style = "";
		foreach ( $link_styles as $link_rule => $link_value ) {
			$link_style .= $link_rule . ':' . $link_value . ';';
		}
		$span_style = "";	
		foreach ( $span_styles as $span_rule => $span_value ) {
			$span_style .= $span_rule . ':' . $span_value . ';';
		}
		$img_style = "";
		foreach ( $img_styles as $img_rule => $img_value ) {
			$img_style .= $img_rule . ':' . $img_value . ';';
		}

		$icon_image = ( $icon ) ? '<img src="' . $icon . '" alt="' . htmlspecialchars( $content ) . '" style="' . $img_style . '" /> ' : '';

		$target = ( $target ) ? ' target="_' . $target . '"' : '';

		return '<a href="' . $link . '" class="su-button su-button-style-' . $style . ' ' . $class . '" style="' . $link_style . '"' . $target . '><span style="' . $span_style . '">' . $icon_image . $content . '</span></a>';
	}

	/**
	 * Shortcode: fancy-link
	 *
	 * @param string $content
	 * @return string Output html
	 */
	function su_fancy_link_shortcode( $atts, $content = null ) {
		extract( shortcode_atts( array(
				'link' => '#',
				'color' => 'black'
				), $atts ) );

		return '<a class="su-fancy-link su-fancy-link-' . $color . '" href="' . $link . '">' . $content . '</a>';
	}

	/**
	 * Shortcode: service
	 *
	 * @param array $atts Shortcode attributes
	 * @param string $content
	 * @return string Output html
	 */
	function su_service_shortcode( $atts, $content = null ) {
		extract( shortcode_atts( array(
				'title' => __( 'Service name', 'satori' ),
				'icon' => su_plugin_url() . '/images/service.png',
				'size' => 32
				), $atts ) );

		return '<div class="su-service"><div class="su-service-title" style="padding: 5px 0 ' . ( $size - 26 )  . 'px ' . ( $size + 7 ) . 'px"><img src="' . $icon . '" width="' . $size . '" height="' . $size . '" alt="' . $title . '" /> ' . $title . '</div><div class="su-service-content" style="padding:0 0 0 ' . ( $size + 7 ) . 'px">' . do_shortcode( $content ) . '</div></div>';
	}

	/**
	 * Shortcode: box
	 *
	 * @param array $atts Shortcode attributes
	 * @param string $content
	 * @return string Output html
	 */
	function su_box_shortcode( $atts, $content = null ) {
		extract( shortcode_atts( array(
				'color' => '#333',
				'title' => __( 'This is box title', 'satori' )
				), $atts ) );

		$styles = array(
			'dark_color' => su_hex_shift( $color, 'darker', 20 ),
			'light_color' => su_hex_shift( $color, 'lighter', 60 ),
			'text_shadow' => su_hex_shift( $color, 'darker', 70 ),
		);

		return '<div class="su-box" style="border:1px solid ' . $styles['dark_color'] . '"><div class="su-box-title" style="background-color:' . $color . '; ' . $styles['light_color'] . '; ' . $styles['text_shadow'] . '">' . $title . '</div><div class="su-box-content">' . su_do_shortcode( $content, 'b' ) . '</div></div>';
	}

	/**
	 * Shortcode: note
	 *
	 * @param array $atts Shortcode attributes
	 * @param string $content
	 * @return string Output html
	 */
	function su_note_shortcode( $atts, $content = null ) {
		extract( shortcode_atts( array(
				'color' => '#fc0'
				), $atts ) );

		$styles = array(
			'dark_color' => su_hex_shift( $color, 'darker', 10 ),
			'light_color' => su_hex_shift( $color, 'lighter', 20 ),
			'extra_light_color' => su_hex_shift( $color, 'lighter', 80 ),
			'text_color' => su_hex_shift( $color, 'darker', 70 )
		);

		return '<div class="su-note" style="background-color:' . $styles['light_color'] . ';border:1px solid ' . $styles['dark_color'] . '"><div class="su-note-shell" style="color:' . $styles['text_color'] . '">' . su_do_shortcode( $content, 'n' ) . '</div></div>';
	}

	/**
	 * Shortcode: private
	 *
	 * @param array $atts Shortcode attributes
	 * @param string $content
	 * @return string Output html
	 */
	function su_private_shortcode( $atts = null, $content = null ) {

		if ( current_user_can( 'publish_posts' ) )
			return '<div class="su-private"><div class="su-private-shell">' . do_shortcode( $content ) . '</div></div>';
	}

	/**
	 * Shortcode: media
	 *
	 * @param array $atts Shortcode attributes
	 * @param string $content
	 * @return string Output html
	 */
	function su_media_shortcode( $atts, $content = null ) {
		extract( shortcode_atts( array(
				'url' => '',
				'width' => 940,
				'height' => 528,
				'jwplayer' => false
				), $atts ) );

		if ( $jwplayer ) {
			$jwplayer = str_replace( '#038;', '&', $jwplayer );
			parse_str( $jwplayer, $jwplayer_options );
		}
		else {
		$jwplayer_options = null;
		}

		$return = '<div class="video-container shortcode-video-container">';
		$return .= ( $url ) ? su_get_media( $url, $width, $height, $jwplayer_options ) : __( 'Please specify media url', 'satori' ); 
		$return .= '</div>';

		return $return;
	}

	/**
	 * Shortcode: table
	 *
	 * @param array $atts Shortcode attributes
	 * @param string $content
	 * @return string Output html
	 */
	function su_table_shortcode( $atts, $content = null ) {
		extract( shortcode_atts( array(
				'style' => 1,
				'file' => false
				), $atts ) );

		$return = '<div class="su-table su-table-style-' . $style . '">';
		$return .= ( $file ) ? su_parse_csv( $file ) : do_shortcode( $content );
		$return .= '</div>';

		return $return;
	}

	/**
	 * Shortcode: pricing
	 *
	 * @param array $atts Shortcode attributes
	 * @param string $content
	 * @return string Output html
	 */
	function su_pricing_shortcode( $atts, $content = null ) {
		extract( shortcode_atts( array(
				'style' => 1
				), $atts ) );

		$return = '<div class="su-pricing su-pricing-style-' . $style . '">';
		$return .= do_shortcode( $content );
		$return .= '<div class="su-spacer"></div></div>';

		return $return;
	}

	/**
	 * Shortcode: plan
	 *
	 * @param array $atts Shortcode attributes
	 * @param string $content
	 * @return string Output html
	 */
	function su_plan_shortcode( $atts, $content = null ) {
		extract( shortcode_atts( array(
				'name' => '&hellip;',
				'price' => '$100',
				'per' => 'per month',
				'width' => 150,
				'primary' => false,
				'class' => false
				), $atts ) );

		$custom_classes = ( $primary ) ? ' su-plan-primary' : '';
		$custom_classes .= ( $class ) ? ' ' . $class : '';

		$return = '<div class="su-plan' . $custom_classes . '" style="width:' . $width . 'px">';
		$return .= '<div class="su-plan-name">' . $name . '</div>';
		$return .= '<div class="su-plan-price">' . $price . '<span class="su-sep">/</span><span class="su-per">' . $per . '</span></div>';
		$return .= '<div class="su-plan-content">';
		$return .= do_shortcode( $content );
		$return .= '</div><div class="su-plan-footer"></div></div>';

		return $return;
	}


	/**
	 * Shortcode: nivo_slider
	 *
	 * @param array $atts Shortcode attributes
	 * @param string $content
	 * @return string Output html
	 */
	function su_nivo_slider_shortcode( $atts, $content = null ) {
		extract( shortcode_atts( array(
				'source' => 'post',
				'link' => 'image',
				'size' => '500x300',
				'limit' => 10,
				'effect' => 'random',
				'speed' => 600,
				'delay' => 3000
				), $atts ) );

		// Get dimensions
		$dimensions = explode( 'x', strtolower( $size ) );
		$width = $dimensions[0];
		$height = $dimensions[1];

		// Define unique slider ID
		$slider_id = uniqid( 'su-nivo-slider_' );

		// Get slides
		$slides = su_build_gallery( $source, $link, $size, $limit );

		// If slides exists
		if ( count( $slides ) > 1 ) {

			$return = '<script type="text/javascript">jQuery(window).load(function(){jQuery("#' . $slider_id . '").nivoSlider({effect:"' . $effect . '",animSpeed:' . $speed . ',pauseTime:' . $delay . '});});</script>';

			$return .= '<div id="' . $slider_id . '" class="su-nivo-slider" style="width:' . $width . 'px;height:' . $height . 'px">';
			foreach ( $slides as $slide ) {
				$return .= '<a href="' . $slide['link'] . '" title="' . $slide['name'] . '"><img src="' . $slide['thumbnail'] . '" alt="' . $slide['name'] . '" width=" ' . $width . 'px " height="' . $height . 'px" /></a>';
			}
			$return .= '</div>';
		}

		// No slides
		else {
			$return = '<p class="su-error"><strong>Nivo slider:</strong> ' . __( 'no attached images, or only one attached image', 'satori' ) . '&hellip;</p>';
		}

		return $return;
	}

	/**
	 * Shortcode: jcarousel
	 *
	 * @param array $atts Shortcode attributes
	 * @param string $content
	 * @return string Output html
	 */
	function su_jcarousel_shortcode( $atts, $content = null ) {
		extract( shortcode_atts( array(
				'source' => 'post',
				'link' => 'image',
				'size' => '150x150',
				'limit' => 10,
				'items' => 3,
				'speed' => 400,
				'margin' => 10
				), $atts ) );

		// Get dimensions
		$dimensions = explode( 'x', strtolower( $size ) );
		$width = $dimensions[0];
		$height = $dimensions[1];

		// Calculate width
		$container_width = round( ( ( $width + $margin ) * $items ) - $margin );

		// Define unique carousel ID
		$carousel_id = uniqid( 'su-jcarousel_' );

		// Get slides
		$slides = su_build_gallery( $source, $link, $size, $limit );

		// If has attachments
		if ( count( $slides ) > 1 ) {

			$return = '<script type="text/javascript">jQuery(document).ready(function(){jQuery("#' . $carousel_id . '").jcarousel({auto:2,scroll:1,wrap:"last",animation:' . $speed . ',initCallback:mycarousel_initCallback});});</script>';

			$return .= '<div class="su-jcarousel" style="width:' . $container_width . 'px;height:' . $height . 'px"><ul id="' . $carousel_id . '">';

			foreach ( $slides as $slide ) {
				$return .= '<li style="width:' . $width . 'px;height:' . $height . 'px;margin-right:' . $margin . 'px"><a href="' . $slide['link'] . '" title="' . $slide['name'] . '"><img src="' . $slide['thumbnail'] . '" alt="' . $slide['name'] . '" width=" ' . $width . ' " height="' . $height . '" /></a></li>';
			}
			$return .= '</ul></div>';
		}

		// No attachments
		else {
			$return = '<p class="su-error"><strong>jCarousel:</strong> ' . __( 'no attached images, or only one attached image', 'satori' ) . '&hellip;</p>';
		}

		return $return;
	}

	/**
	 * Shortcode: custom_gallery
	 *
	 * @param array $atts Shortcode attributes
	 * @param string $content
	 * @return string Output html
	 */
	function su_custom_gallery_shortcode( $atts, $content = null ) {
		extract( shortcode_atts( array(
				'style' => 1,
				'source' => 'post',
				'link' => 'image',
				'description' => false,
				'size' => '200x200',
				'limit' => 10
				), $atts ) );

		// Get dimensions
		$dims = explode( 'x', strtolower( $size ) );
		$width = $dims[0];
		$height = $dims[1];

		// Define unique gallery ID
		$gallery_id = uniqid( 'su-custom-gallery_' );

		// Get slides
		$slides = su_build_gallery( $source, $link, $size, $limit );

		// If slides exists
		if ( count( $slides ) > 1 ) {

			$return = '<div id="' . $gallery_id . '" class="su-custom-gallery su-custom-gallery-style-' . $style . '">';
			foreach ( $slides as $slide ) {

				// Description
				$desc = ( $description ) ? '<span>' . $slide['description'] . '</span>' : false;
				$return .= '<a href="' . $slide['link'] . '" title="' . $slide['name'] . '"><img src="' . $slide['thumbnail'] . '" alt="' . $slide['name'] . '" width="' . $width . '" height="' . $height . '" />' . $desc . '</a>';
			}
			$return .= '<div class="su-spacer"></div></div>';
		}

		// No slides
		else {
			$return = '<p class="su-error"><strong>Custom gallery:</strong> ' . __( 'no attached images, or only one attached image', 'satori' ) . '&hellip;</p>';
		}

		return $return;
	}

	/**
	 * Shortcode: permalink
	 *
	 * @param string $content
	 * @return string Output html
	 */
	function su_permalink_shortcode( $atts, $content = null ) {
		extract( shortcode_atts( array(
				'p' => 1,
				'target' => ''
				), $atts ) );

		$text = ( $content ) ? $content : get_the_title( $p );
		$tgt = ( $target ) ? ' target="_' . $target . '"' : '';

		return '<a href="' . get_permalink( $p ) . '" title="' . $text . '"' . $tgt . '>' . $text . '</a>';
	}

	/**
	 * Shortcode: bloginfo
	 *
	 * @param string $content
	 * @return string Output html
	 */
	function su_bloginfo_shortcode( $atts, $content = null ) {
		extract( shortcode_atts( array(
				'option' => 'name'
				), $atts ) );

		return '<span class="su-bloginfo">'.get_bloginfo( $option ).'</span>';
	}

	/**
	 * Shortcode: subpages
	 *
	 * @param string $content
	 * @return string Output html
	 */
	function su_subpages_shortcode( $atts, $content = null ) {
		extract( shortcode_atts( array(
				'depth' => 1,
				'p' => false
				), $atts ) );

		global $post;

		$child_of = ( $p ) ? $p : get_the_ID();

		$return = wp_list_pages( array(
			'title_li' => '',
			'echo' => 0,
			'child_of' => $child_of,
			'depth' => $depth
			) );

		return ( $return ) ? '<ul class="su-subpages">' . $return . '</ul>' : false;
	}

	/**
	 * Shortcode: siblings pages
	 *
	 * @param string $content
	 * @return string Output html
	 */
	function su_siblings_shortcode( $atts, $content = null ) {
		extract( shortcode_atts( array(
				'depth' => 1
				), $atts ) );

		global $post;

		$return = wp_list_pages( array(
			'title_li' => '',
			'echo' => 0,
			'child_of' => $post->post_parent,
			'depth' => $depth,
			'exclude' => $post->ID
			) );

		return ( $return ) ? '<ul class="su-siblings">' . $return . '</ul>' : false;
	}

	/**
	 * Shortcode: menu
	 *
	 * @param string $content
	 * @return string Output html
	 */
	function su_menu_shortcode( $atts, $content = null ) {
		extract( shortcode_atts( array(
				'name' => 1
				), $atts ) );

		$return = wp_nav_menu( array(
			'echo' => false,
			'menu' => $name,
			'container' => false,
			'fallback_cb' => 'su_menu_shortcode_fb_cb'
			) );

		return ( $name ) ? $return : false;
	}

	/**
	 * Fallback callback function for menu shortcode
	 *
	 * @return string Text message
	 */
	function su_menu_shortcode_fb_cb() {
		return __( 'This menu doesn\'t exists, or has no elements', 'satori' );
	}

	/**
	 * Shortcode: document
	 *
	 * @param array $atts Shortcode attributes
	 * @param string $content
	 * @return string Output html
	 */
	function su_document_shortcode( $atts, $content = null ) {
		extract( shortcode_atts( array(
				'width' => 600,
				'height' => 400,
				'file' => ''
				), $atts ) );

		return '<iframe src="http://docs.google.com/viewer?embedded=true&url=' . $file . '" width="' . $width . '" height="' . $height . '" class="su-document"></iframe>';
	}

	/**
	 * Shortcode: gmap
	 *
	 * @param array $atts Shortcode attributes
	 * @param string $content
	 * @return string Output html
	 */
	function su_gmap_shortcode( $atts, $content = null ) {
		extract( shortcode_atts( array(
				'width' => 600,
				'height' => 400,
				'address' => 'Russia, Moscow'
				), $atts ) );

		return '<iframe width="' . $width . '" height="' . $height . '" src="http://maps.google.com/maps?q=' . urlencode( $address ) . '&amp;output=embed" class="su-gmap"></iframe>';
	}

	/**
	 * Shortcode: members
	 *
	 * @param array $atts Shortcode attributes
	 * @param string $content
	 * @return string Output html
	 */
	function su_members_shortcode( $atts, $content = null ) {
		extract( shortcode_atts( array(
				'style' => 1,
				'login' => 1
				), $atts ) );

		// Logged user
		if ( is_user_logged_in() && !is_null( $content ) && !is_feed() ) {
			return do_shortcode( $content );
		}

		// Not logged user, show login message
		elseif ( $login == 1 ) {
			return '<div class="su-members su-members-style-' . $style . '"><span class="su-members-shell">' . __( 'This content is for members only.', 'satori' ) . ' <a href="' . wp_login_url( get_permalink( get_the_ID() ) ) . '">' . __( 'Please login', 'satori' ) . '</a>.' . '</span></div>';
		}
	}

	/**
	 * Shortcode: guests
	 *
	 * @param string $content
	 * @return string Output html
	 */
	function su_guests_shortcode( $atts = null, $content = null ) {

		// Logged user
		if ( !is_user_logged_in() && !is_null( $content ) ) {
			return '<div class="su-guests">' . do_shortcode( $content ) . '</div>';
		}
	}

	/**
	 * Shortcode: feed
	 *
	 * @param array $atts Shortcode attributes
	 * @param string $content
	 * @return string Output html
	 */
	function su_feed_shortcode( $atts, $content = null ) {
		extract( shortcode_atts( array(
				'url' => get_bloginfo_rss( 'rss2_url' ),
				'limit' => 3
				), $atts ) );

		include_once( ABSPATH . WPINC . '/rss.php' );

		return '<div class="su-feed">' . wp_rss( $url, $limit ) . '</div>';
	}

	/**
	 * Shortcode: tweets
	 *
	 * @param array $atts Shortcode attributes
	 * @param string $content
	 * @return string Output html
	 */
	function su_tweets_shortcode( $atts, $content = null ) {
		extract( shortcode_atts( array(
				'username' => 'twitter',
				'consumerkey' => '',
				'consumersecret' => '',
				'accesstoken' => '',
				'accesstokensecret' => '',
				'limit' => 3
				), $atts ) );

		$return = '<div class="su-tweets su-tweets-style-' . $style . '">';
		$return .= su_get_tweets( $username, $limit, $consumerkey, $consumersecret, $accesstoken, $accesstokensecret );
		$return .= '</div>';

		return $return;
	}
	
	
	// Shortcode: custom post list
	
	function su_display_posts_shortcode( $atts ) {

	// Pull in shortcode attributes and set defaults
	extract( shortcode_atts( array(
		'category'        => '',
		'offset'          => 0,
		'order'           => 'DESC',
		'orderby'         => 'date',
		'post_type'       => 'post',
		'numberposts'  => 5
	), $atts ) );

	// Set up initial query for post
	$args = array(
		'category'  => $category,
		'order' => $order,
		'orderby' => $orderby,
		'post_type' => $post_type,
		'numberposts' => $numberposts,
		'offset' => $offset,
		'suppress_filters' => false 
	);
	apply_filters( 'display_posts_shortcode_args', $args, $atts );
	
	$postlist = wp_get_recent_posts($args);
	$postcount = 0;
	$expmore = __('Expand','satori').' &raquo;';
	$expclose = __('Close','satori');
	$su_posts = '';
	global $more;
	foreach ($postlist as $postlistitem) {
	
	$more = 0; 
	$arc_year = get_the_time('Y', $postlistitem["ID"]); $arc_month = get_the_time('m', $postlistitem["ID"]); $arc_day = get_the_time('d', $postlistitem["ID"]);
	$postdate = get_the_time('F j, Y', $postlistitem["ID"]);;
	$cats = get_the_category($postlistitem["ID"]);
	if ( has_post_thumbnail($postlistitem["ID"]) ) { /* loads the post's featured thumbnail, requires Wordpress 3.0+ */ $postthumb = '<div class="featured-thumbnail">'.get_the_post_thumbnail($postlistitem["ID"]).'</div>'; } 
	$su_posts .= '<div class="post-single">
			<div class="post-wrapper">
				<div class="post-header">
				<h2><a href="'.get_permalink($postlistitem["ID"]).'" title="'.$postlistitem['post_title'].'" rel="bookmark">'.$postlistitem['post_title'].'</a></h2>
				</div><div class="clearleft"></div><!--.postHeader-->'.$postthumb.'
				<div class="post-content">';
				
				$content = preg_replace('/<!--more.*/s', '', $postlistitem['post_content']);
				$su_posts .= $content; 
 
				
				$su_posts .= '<div class="post-meta">
					<span class="meta-img"><img src="'.get_template_directory_uri().'/images/misc_icons/grey_light/clock_12x12.png" alt="date" /></span>
					<span class="meta-date">'.$postdate.'</span>
					<span class="meta-img"><img src="'.get_template_directory_uri().'/images/misc_icons/grey_light/user_9x12.png" alt="author" /></span>
					<span class="meta-author">'.$postlistitem['post_author'].'</span>
					<span class="meta-img"><img src="'.get_template_directory_uri().'/images/misc_icons/grey_light/list_12x11.png" alt="category" /></span>
					<span class="meta-cat">'.$cats[0]->cat_name.'</span>
				</div><!--.postMeta-->
				<div class="clearboth"></div>
			</div>
			</div>
			</div><!--.post-single-->';	
			$postthumb = null;
			$content = null;
	}
	$su_post_list = '<div id="shortcode-postlist">'.$su_posts.'</div>';
	
	return $su_post_list;
}
	
	

?>